==> jasperreports-server-cp-4.1.0-src.zip: jasperreports-server-cp-4.1.0-src/jasperserver/jasperserver-search/src/main/java/com/jaspersoft/jasperserver/search/filter/SearchAttributesHelper.java <==
/*
 * Copyright (C) 2005 - 2011 Jaspersoft Corporation. All rights reserved.
 * http://www.jaspersoft.com.
 *
 * Unless you have purchased  a commercial license agreement from Jaspersoft,
 * the following license terms  apply:
 *
 * This program is free software: you can redistribute it and/or  modify
 * it under the terms of the GNU Affero General Public License  as
 * published by the Free Software Foundation, either version 3 of  the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero  General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public  License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

package com.jaspersoft.jasperserver.search.filter;

import com.jaspersoft.jasperserver.api.common.domain.ExecutionContext;
import com.jaspersoft.jasperserver.search.common.SearchAttributes;

/**
 * Search attributes helper.
 *
 * @author Yuriy Plakosh
 * @version $Id$
 */
public class SearchAttributesHelper {
    public static SearchAttributes extract(ExecutionContext context) {
        SearchAttributes searchAttributes = null;

        if (context.getAttributes() != null) {
            for(Object o : context.getAttributes()) {
                if (o instanceof SearchAttributes) {
                    searchAttributes = (SearchAttributes) o;
                }
            }
        }

        return searchAttributes;
    }
}

==> jasperreports-server-cp-5.1.0-src.zip: jasperreports-server-cp-5.1.0-src/jasperserver/jasperserver-search/src/main/java/com/jaspersoft/jasperserver/search/filter/SearchAttributesHelper.java <==
/*
 * Copyright (C) 2005 - 2011 Jaspersoft Corporation. All rights reserved.
 * http://www.jaspersoft.com.
 *
 * Unless you have purchased  a commercial license agreement from Jaspersoft,
 * the following license terms  apply:
 *
 * This program is free software: you can redistribute it and/or  modify
 * it under the terms of the GNU Affero General Public License  as
 * published by the Free Software Foundation, either version 3 of  the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero  General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public  License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

package com.jaspersoft.jasperserver.search.filter;

import com.jaspersoft.jasperserver.api.common.domain.ExecutionContext;
import com.jaspersoft.jasperserver.search.common.SearchAttributes;

/**
 * Search attributes helper.
 *
 * @author Yuriy Plakosh
 * @version $Id: SearchAttributesHelper.java 24041 2012-06-06 03:25:17Z carbiv $
 */
public class SearchAttributesHelper {
    public static SearchAttributes extract(ExecutionContext context) {
        SearchAttributes searchAttributes = null;

        if (context!=null && context.getAttributes() != null) {
            for(Object o : context.getAttributes()) {
                if (o instanceof SearchAttributes) {
                    searchAttributes = (SearchAttributes) o;
                }
            }
        }

        return searchAttributes;
    }
}
